# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)




# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)

# CCI Progress
progress.rda <- file.path(parent.dir, "Prepared Data", "CCI Progress.rda")
load(progress.rda)
head(network_totals)
head(cai_totals)



# Total budgets ####

# Lookup budgets
d <- budget[grants]

# Rename
old <- c("federal", "matching", "total")
new <- c("Federal", "Match", "Total")
setnames(d, old, new)

# Millions
d[, new := lapply(.SD, "/", 1e6), .SDcols = new, with = FALSE]

# Totals - all except excluded and defunded
tabular(Heading("Total") * sum * (Federal + Match + Total) * 
          Format(formatC(digits = 0, big.mark = ",", format = "f")) + 
          Heading("Number of grants") * 1 ~ 
          Grant_Type + 1, d[Defunded == "" & Excluded == ""])

# Totals - excluded (public safety)
tabular(Heading("Total") * sum * (Federal + Match + Total) * 
          Format(formatC(digits = 0, big.mark = ",", format = "f")) + 
          Heading("Number of grants") * 1 ~ 
          Grant_Type + 1, d[Defunded == "" & Excluded != ""])

# Totals - defunded (except declined)
tabular(Heading("Total") * sum * (Federal + Match + Total) * 
          Format(formatC(digits = 0, big.mark = ",", format = "f")) + 
          Heading("Number of grants") * 1 ~ 
          Grant_Type + 1, d[Defunded != "" & !is.na(Total)])



# CCI activities ####

# Lookup progress and budgets 
d <- budget[cai_totals[network_totals[grants[Grant_Type == "CCI"]]]]

# Drop excluded and defunded
d <- d[Excluded == ""][Defunded == ""]

# Reshape
fib.vars <- c("NetMileDeploy_Num", "NetMileLease_Num", "ExistMileUpgrade_Num", 
              "ExistMileLease_Num")
d <- melt(d, id.vars = c("Award_Num", "Case_Study"), measure.vars = c(
  fib.vars, "ComInst_Total_Num", "InterconnectPoints_Num", "SignAgreemnt_Num"))
levels(d$variable) <- replace(
  levels(d$variable), levels(d$variable) %in% fib.vars, "fiber_infrastructure")

# Totals
tabular(Heading() * variable * Heading() * value * Heading() * sum ~
          Case_Study + 1, d)
