# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load analysis ####

# Incidence Analysis
incidence.rda <- file.path(parent.dir, "Statistical Analysis", 
                           "Incidence Analysis.rda")
load(incidence.rda)
head(incidence)

# Effect on Availability
effect.rda <- file.path(parent.dir, "Statistical Analysis",
                        "Effect on Availability.rda")
load(effect.rda)
head(effects.intervals)



# Figure 1. Estimated Effect of BTOP on Broadband Availability in the CCI Case 
# Study Sample Service Area for Different Populations of Interest ####

# Resampled incidence and overall effects
d <- copy(incidence)
o <- effects.intervals[J("NTIA", "Availability", "Primary")]
o[, Population := "Evaluation Study Sample"]

# Combine
d <- rbind(d, o[, names(d), with = FALSE])[
  , Population := as.character(Population)]
d[, Population := factor(Population, c(
  d[Population != "Evaluation Study Sample"][order(effect), Population],
  "Evaluation Study Sample"))]

# Forest plot
(vuln_pop_compare <- ggplot(d, aes(effect, Population)) + 
   geom_vline(aes(xintercept = 0), linetype = 2) +
   geom_segment(aes(x = lower, xend = upper, yend = Population, 
                    linetype = "95% Confidence Interval"), size = 1.75,
                color = "lightgrey") +
   geom_point(aes(shape = "Estimate"), size = 5) + 
   scale_shape_manual(values = 15) +
   scale_x_continuous("Effect", label = percent) +
   theme_btop() +
   theme(legend.position = "bottom", 
         legend.direction = "horizontal"))

# Save
ggsave(file.path(sec0, "Figure 1.png"), vuln_pop_compare, width = 12.2, 
       height = 5)
