# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)



# Table. Average BTOP Budgets (in Millions) ####

# Lookup budgets
d <- budget[grants]

# Drop excluded and defunded
d <- d[Excluded == ""][Defunded == ""]

# Rename
old <- c("federal", "matching", "total")
new <- c("Federal", "Match", "Total")
setnames(d, old, new)

# Millions
d[, new := lapply(.SD, "/", 1e6), .SDcols = new, with = FALSE]

# Table
budget_tab <- tabular((Heading("Average") * mean + Heading("Total") * sum) * (
  Federal + Match + Total) * 
    Format(formatC(digits = 1, big.mark = ",", format = "f")) + 
    Heading("Number of grants") * 1 ~ 
    Heading() * Grant_Type * (Heading() * Case_Study + 1), d)
(budget_tab <- budget_tab[, c(1, 3, 4, 6, 7, 9)])

# Write
write.xlsx.tabular(budget_tab, file.path(sec1, "Table 2.xlsx"))
