# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)

# SBA Subscribers
subscr.rda <- file.path(parent.dir, "Prepared Data", "SBA Subscribers.rda")
load(subscr.rda)
head(sba_subscr_total)



# Table 5. SBA Household Connections ####

# Lookup budgets and subscribers 
d <- budget[sba_subscr_total[grants[Grant_Type == "SBA"]]]

# Drop defunded
d <- d[Defunded == ""]

# Dollars per subscriber in ESS without CETF - for endnote in text
d[Case_Study != "Rest of BTOP"][!grepl("Emerging", Recipient)][
  , sum(total) / sum(hhold_cum)]

# Aggregate
sdc <- c("total", "hhold_cum")
cs <- d[, lapply(.SD, sum), .SDcols = sdc, by = Case_Study]
ab <- d[, lapply(.SD, sum), .SDcols = sdc, 
        by = list(Case_Study = rep("All", nrow(d)))]

# Bind
d <- rbind(cs, ab)

# Calculate
d[, dollarper := total / hhold_cum]

# Millions
d[, total := total / 1e6]

# Table
sba_subscr_budg <- tabular((
  Heading("Household subscribers") * hhold_cum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) + 
    Heading("Dollars spent per household subscriber") * dollarper * 
    Format(sprintf("$%.2f"))) * Heading() * sum ~ Heading() * Case_Study, d)
(sba_subscr_budg <- sba_subscr_budg[, -2])

# Write
write.xlsx.tabular(sba_subscr_budg, file.path(sec1, "Table 5.xlsx"))
