# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)



# Table 6. CCI Projects vs. Sample ####

# Lookup budgets
d <- budget[grants[Grant_Type == "CCI"]]

# Drop excluded and defunded
d <- d[Excluded == ""][Defunded == ""]

# Millions
d[, total := total / 1e6]

# Average project size
d1 <- dcast(d, Case_Study ~ "Average project size (millions)", 
            value.var = "total", fun.aggregate = mean, margins = "Case_Study")

# Count
d2 <- dcast(d, Case_Study ~ "Count", value.var = "Case_Study", 
            fun.aggregate = length, margins = "Case_Study")

# Total
d3 <- dcast(d, Case_Study ~ "Total expenditures (millions)",
            value.var = "total", fun.aggregate = sum, margins = "Case_Study")

# Merge
d <- as.data.table(Reduce(merge, list(d1, d2, d3)))

# Percent
d[, "Percent of CCI projects" := Count / d[Case_Study == "(all)", Count]]
d[, "Percent of CCI expenditures"	:= `Total expenditures (millions)` / 
    d[Case_Study == "(all)", `Total expenditures (millions)`]]

# Format
d[, 2 := lapply(.SD, sprintf, fmt = "$%.0f"), .SDcols = 2]
d[, 4 := lapply(.SD, function(x) paste0("$", formatC(x, 0, big.mark = ",", 
                                                     format = "f"))),
  .SDcols = 4]
d[, 5:6 := lapply(lapply(.SD, "*", 100), sprintf, fmt = "%.0f%%"), 
  .SDcols = 5:6]

# Reshape
d[, Count := as.character(Count)]
setnames(d, "Count", "Number of projects")
d <- melt(d, id.vars = 1)

# Order factors
levels(d$Case_Study)[3] <- "All"

# Table
cci_sample_pop <- tabular(
  Heading() * variable ~ 
    Heading() * Case_Study * Heading() * value * Heading() * identity, d)
(cci_sample_pop <- cci_sample_pop[, -2])

# Write
write.xlsx.tabular(cci_sample_pop, file.path(sec1, "Table 6.xlsx"))
