# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Budgets
budget.rda <- file.path(parent.dir, "Prepared Data", "Budgets.rda")
load(budget.rda)
head(budget)

# CCI Progress
progress.rda <- file.path(parent.dir, "Prepared Data", "CCI Progress.rda")
load(progress.rda)
head(network_totals)
head(cai_totals)



# Table. CCI Network Summary ####

# Lookup progress and budgets 
d <- budget[cai_totals[network_totals[grants[Grant_Type == "CCI"]]]]

# Drop excluded and defunded
d <- d[Excluded == ""][Defunded == ""]

# Aggregate
sdc <- c("total", "NetMileDeploy_Num", "ComInst_Total_Num", "SignAgreemnt_Num")
cs <- d[, lapply(.SD, sum), .SDcols = sdc, by = Case_Study]
ab <- d[, lapply(.SD, sum), .SDcols = sdc, 
        by = list(Case_Study = rep("All", nrow(d)))]

# Bind
d <- rbind(cs, ab)

# Calculate
d[, dollarper_mile := total / NetMileDeploy_Num]
d[, dollarper_inst := total / ComInst_Total_Num]
d[, dollarper_agmt := total / SignAgreemnt_Num]

# Millions
d[, total := total / 1e6]

# Reshape
d <- melt(d, id.vars = 1)

# Row labels
d[, variable := factor(variable, c(
  "total", "NetMileDeploy_Num", "dollarper_mile", "ComInst_Total_Num", 
  "dollarper_inst", "SignAgreemnt_Num", "dollarper_agmt"), c(
    "Total budgeted (millions)", "New network miles deployed", 
    "Budgeted dollars per mile", "CAIs connected", "Budgeted dollars per CAI", 
    "New agreements signed with last mile and wholesale providers",
    "Budgeted dollars per agreement (millions)"))]

# Formatted
d[variable == "Budgeted dollars per agreement (millions)", value := value / 1e6]
d[!grepl("^Budgeted.*millions", variable), 
  v := formatC(value, digits = 0, big.mark = ",", format = "f")]
d[grepl("^Budgeted.*millions", variable), 
  v := formatC(value, digits = 1, big.mark = ",", format = "f")]
d[grep("budgeted", variable, ignore.case = TRUE), v := paste0("$", v)]

# Table
cci_net_budg <- tabular(
  Heading() * variable ~ 
    Heading() * Case_Study * Heading() * v * Heading() * identity, d)
(cci_net_budg <- cci_net_budg[, -2])

# Write
write.xlsx.tabular(cci_net_budg, file.path(sec1, "Table 7.xlsx"))
