# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Reorder factor 
grants[, Case_Study := factor(Case_Study, rev(levels(Case_Study)))]

# CCI Progress
progress.rda <- file.path(parent.dir, "Prepared Data", "CCI Progress.rda")
load(progress.rda)
head(network_progress)



# Figure 6. Cumulative Signed Third-Party Service Provider and Broadband 
# Wholesaler Agreements as of December 31, 2013 ####

# Lookup agreements
agreements <- network_progress[grants[Grant_Type == "CCI"]]

# Drop excluded and defunded
agreements <- agreements[Excluded == ""][Defunded == ""]

# Roll up
agreements <- agreements[, list(signed = sum(SignAgreemnt_Num),
                                rolled = any(rolled)), 
                         keyby = list(quarter, Case_Study)]

# Positions for "Estimated"
agreements[, qsum := sum(signed), by = quarter]
agreements[rolled & Case_Study == "Evaluation Study Sample", 
           epos := signed / 2 + (qsum - signed)]
agreements[rolled & Case_Study != "Evaluation Study Sample", epos := signed / 2]

# Trial and error determines full or abbreviated "Estimated"
agreements[, elab := "Estimated"]
agreements[quarter <= "2013-06-30" & Case_Study == "Evaluation Study Sample", 
           elab := "Est."]

# Plot
(inter_signed <- ggplot(agreements, aes(quarter, signed)) + 
   geom_bar(stat = "identity", aes(fill = Case_Study, order = Case_Study)) + 
   scale_fill_manual(values = c("black", "#800000")) + 
   geom_text(aes(y = epos, label = elab), color = "white", angle = 90,
             size = 5) +
   scale_x_date(label = date_format("%B\n%Y")) + 
   scale_y_continuous(label = comma) + 
   theme_btop() + 
   theme(axis.title = element_blank()))

# Save
ggsave(file.path(sec4, "Figure 6.png"), inter_signed, width = 12.2, height = 7)

# Figure talk
dcast(agreements, quarter ~ Case_Study, sum, margins = "Case_Study", 
      value.var = "signed")
