# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# SBA Subscribers
subscr.rda <- file.path(parent.dir, "Prepared Data", "SBA Subscribers.rda")
load(subscr.rda)
head(sba_subscribers)



# Figure 10. Cumulative SBA New Household Subscribers ####

# Lookup new household subscribers
subs <- sba_subscribers[grants[Grant_Type == "SBA"]]

# Drop defunded
subs <- subs[Defunded == ""]

# Roll up
subs <- subs[, list(subs = sum(hhold_cum), rolled = any(rolled)), 
             keyby = list(quarter, Case_Study)]

# Positions for "Estimated"
subs[, qsum := sum(subs), by = quarter]
subs[rolled & Case_Study == "Evaluation Study Sample", epos := subs / 2 + 
       (qsum - subs)]
subs[rolled & Case_Study != "Evaluation Study Sample", epos := subs / 2]

# Trial and error determines full or abbreviated "Estimated"
subs[, elab := "Estimated"]

# Factor labels
subs[, Case_Study := factor(Case_Study, rev(levels(Case_Study)))]

# Plot
(subscribers <- ggplot(subs, aes(quarter, subs)) + 
   geom_bar(stat = "identity", aes(fill = Case_Study, order = Case_Study)) + 
   scale_fill_manual(values = c("black", "#800000")) + 
   geom_text(aes(y = epos, label = elab), color = "white", angle = 90, 
             size = 5) +
   scale_x_date(label = date_format("%B\n%Y")) + 
   scale_y_continuous(label = comma) + 
   theme_btop() + 
   theme(axis.title = element_blank()))

# Save
ggsave(file.path(sec6, "Figure 10.png"), subscribers, width = 12.2, height = 7)

# Figure talk
dcast(subs, quarter ~ Case_Study, sum, margins = "Case_Study", 
      value.var = "subs")
sba_subscribers[quarter == "2013-12-31", sum(bus_cum)]
