# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# CCI Progress
progress.rda <- file.path(parent.dir, "Prepared Data", "CCI Progress.rda")
load(progress.rda)
head(cai_progress)



# Figure Cumulative CCI Community Anchor Institution Connections ####

# Lookup installations and upgrades
cais <- cai_progress[grants[Grant_Type == "CCI"]]

# Drop excluded and defunded
cais <- cais[Excluded == ""][Defunded == ""]

# Roll up
cais <- cais[, list(connected = sum(ComInst_Total_Num), rolled = any(rolled)),
             keyby = list(quarter, Case_Study)]

# Positions for "Estimated"
cais[, qsum := sum(connected), by = quarter]
cais[rolled & Case_Study == "Evaluation Study Sample", epos := connected / 2 +
       (qsum - connected)]
cais[rolled & Case_Study != "Evaluation Study Sample", epos := connected / 2]

# Trial and error determines full or abbreviated "Estimated"
cais[, elab := "Estimated"]

# Factor labels
cais[, Case_Study := factor(Case_Study, rev(levels(Case_Study)))]

# Plot
(connections <- ggplot(cais, aes(quarter, connected)) + 
   geom_bar(stat = "identity", aes(fill = Case_Study, order = Case_Study)) + 
   scale_fill_manual(values = c("black", "#800000")) + 
   geom_text(aes(y = epos, label = elab), color = "white", angle = 90, 
             size = 5) +
   scale_x_date(label = date_format("%B\n%Y")) + 
   scale_y_continuous(label = comma) + 
   theme_btop() + 
   theme(axis.title = element_blank()))

# Save
ggsave(file.path(sec6, "Figure 9.png"), connections, width = 12.2, height = 7)

# Figure talk
dcast(cais, quarter ~ Case_Study, sum, margins = "Case_Study", 
      value.var = "connected")
