# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# PCC Centers Established and Improved
centers.rda <- file.path(parent.dir, "Prepared Data", 
                         "PCC Centers Established and Improved.rda")
load(centers.rda)
head(est_impr)



# Table 15. New and Upgraded PCCs as of December 2013 ####

# Lookup totals
d <- est_impr[Year_Desc == 2013][grants[Grant_Type == "PCC"], 
                                 allow.cartesian = TRUE]

# Drop defunded
d <- d[Defunded == ""]

# Combine established and improved
d[, pccs := established + improved]

# Change labels
levels(d$category) <- replace(
  levels(d$category), levels(d$category) == "School (K-12)", "Schools (K-12)")
levels(d$category) <- replace(
  levels(d$category), levels(d$category) == "Library", "Libraries")
levels(d$category) <- replace(
  levels(d$category), levels(d$category) == "Community College", 
  "Community Colleges")
levels(d$category) <- replace(
  levels(d$category), 
  levels(d$category) == "Job Training and/or Economic Development Institution",
  "Job Training and/or Economic Development Institutions")
levels(d$category) <- replace(
  levels(d$category), levels(d$category) == "Medical or Healthcare Facility",
  "Medical or Healthcare Facilities")

# Table
new_upgr_pccs <- tabular(
  (Heading("Institution Type") * category + Heading("All institutions") * 1) * 
    Heading() * pccs * Heading() * sum *
    Format(formatC(big.mark = ",", digits = 0, format = "f")) ~ 
    Heading() * Case_Study + 1, d)
(new_upgr_pccs <- new_upgr_pccs[, -2])

# Write
write.xlsx.tabular(new_upgr_pccs, file.path(sec6, "Table 15.xlsx"))
