# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# SBA Locations
locs.rda <- file.path(parent.dir, "Prepared Data", "SBA Locations.rda")
load(locs.rda)
head(sba_locs)



# Table 16. SBA Institutions ####

# Table
sba_inst <- tabular(
  Heading("Institution Type") * type + Heading("All institutions") * 1 ~ 
    (Heading() * Case_Study + 1) * 
    Format(formatC(big.mark = ",", digits = 0, format = "f")),
  grants[sba_locs])
(sba_inst <- sba_inst[, -2])

# Write
write.xlsx.tabular(sba_inst, file.path(sec6, "Table 16.xlsx"))
