# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# PCC and SBA Training Hours and Participants
training.rda <- file.path(parent.dir, "Prepared Data", 
                          "PCC and SBA Training Hours and Participants.rda")
load(training.rda)
head(training.lab)



# Table 18. PCC and SBA Training Hours ####

# Lookup
d <- training.lab[grants[Grant_Type %in% c("PCC", "SBA")], 
                  allow.cartesian = TRUE]

# Drop defunded
d <- d[Defunded == ""]

# Separate lab and non-lab
non <- dcast(d[`Focus Area` != "Open Lab"], `Focus Area` ~ Grant_Type, sum, 
             value.var = "Hours", margins = "Focus Area")
lab <- dcast(d[`Focus Area` == "Open Lab"], `Focus Area` ~ Grant_Type, sum, 
             value.var = "Hours")

# Combine
train <- as.data.table(rbind(non, lab))
train[`Focus Area` == "(all)", "Focus Area" := "Total"]
train[, Total := PCC + SBA]

# Format
train[, 2:4 := lapply(.SD, formatC, digits = 0, format = "f", big.mark = ","),
      .SDcols = 2:4]

# Print
train

# Write
write.xlsx(train, file.path(sec6, "Table 18.xlsx"), row.names = FALSE)
