# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load intermediate files ####

# Grants list
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Unique users
users.rda <- file.path(parent.dir, "Prepared Data", "PCC Unique Users.rda")
load(users.rda)
head(users)

# Labor force statistics
labor.rda <- file.path(parent.dir, "Prepared Data",
                       "PCC and SBA Labor Force Statistics.rda")
load(labor.rda)
head(labor_force)

# Job search training
job.rda <- file.path(parent.dir, "Prepared Data", 
                     "PCC and SBA Job Search Training Summary.rda")
load(job.rda)
head(job_search)



# Calculations ####

# Kuhn and Mansour (2013) ####
# Estimated that unemployment durations are 24 percent shorter for 
# Internet job searchers than offline job searchers.

# Data
pcc.w.1a <- grants[Grant_Type == "PCC"][Defunded == ""] # PCC grants
pcc.w.1a <- users[pcc.w.1a] # Total unique users
pcc.w.1a <- labor_force[pcc.w.1a] # Labor force stats
pcc.w.1a <- job_search[pcc.w.1a] # Job search trainees
pcc.w.1a[is.na(participants), participants := 0]

# Users who search
pcc.w.1a[, users_search := unique_users * labor_participation_15_64 * 
           unemployment_rate]

# Number of searchers
pcc.w.1a[, `New Internet job searchers` := users_search + participants]

# Total decrease in unemployment duration
pcc.w.1a[, `Decreased duration` := `New Internet job searchers` * 
           avg_duration * .237]

# Benefit = Total decrease * (minimum wage * 40)
pcc.w.1a[, `Total Economic Benefit` := (`Decreased duration` * 
                                          (min_wage * 40)) / 1e6]



# Results ####

# Job searchers and unemployment reduction - by case study
# The case study numbers are referred to in table talk
search_reduct <- tabular(Heading("Estimate") * (
  `New Internet job searchers` + `Decreased duration`) * Heading() * sum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) ~ 
    Heading() * Case_Study + Heading("Estimate") * 1, pcc.w.1a)
(search_reduct <- search_reduct[, 3])

# Total benefit due to unemployment reduction - by case study
# Referred to in table talk
(totalben <- tabular(
  Heading("Estimate") * `Total Economic Benefit` * Heading() * sum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) ~
    Heading() * Case_Study + Heading("All PCC Grants") * 1, pcc.w.1a))


# Write to files ####

# Job searchers and unemployment reduction - by case study
write.xlsx.tabular(search_reduct, file.path(appC, "PCC.W.1 - Table 40.xlsx"))

# Total benefit due to unemployment reduction - by case study
write.xlsx.tabular(totalben, file.path(appC, "PCC.W.1 - Table E.xlsx"))
