# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load intermediate files ####

# Grants list
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Unique users
users.rda <- file.path(parent.dir, "Prepared Data", "PCC Unique Users.rda")
load(users.rda)
head(users)

# Entrepreneurship training
entrain.rda <- file.path(parent.dir, "Prepared Data", 
                         "PCC and SBA Entrepreneurship Training Summary.rda")
load(entrain.rda)
head(entrepreneurship)



# Calculations ####

# Becker et al. (2010): 7% engaged in "activities related to starting or 
# managing a business of their own", 3.3% started a business, 3.5% looked for 
# new customers, 1.7% grew business

# Data
pcc.w.2 <- grants[Grant_Type == "PCC"][Defunded == ""] # PCC grants
pcc.w.2 <- users[pcc.w.2] # Total unique users
pcc.w.2 <- entrepreneurship[pcc.w.2] # Entrepreneurship trainees
pcc.w.2[, participants := replace(participants, is.na(participants), 0)]

# Number engaged in entrepreneurial endeavors
pcc.w.2[, entrep_endeav := participants + unique_users * .07]

# Started a business
pcc.w.2[, start_business := entrep_endeav * (0.033 / .07)]

# Looked for new customers
pcc.w.2[, searched_customers := entrep_endeav * (0.035 / .07)]

# Grew business
pcc.w.2[, grew_business := entrep_endeav * (0.017 / .07)]



# Results ####
setnames(pcc.w.2, "unique_users", "Unique users")
setnames(pcc.w.2, "participants", "Entrepreneurship trainees")
setnames(pcc.w.2, "entrep_endeav", "Engaged in entrepreneurial activities")
setnames(pcc.w.2, "start_business", "Started a business")
setnames(pcc.w.2, "searched_customers", "Looked for new customers")
setnames(pcc.w.2, "grew_business", "Grew their business")

# Total Estimated Number of Individuals Engaged in Any Entrepreneurial Activity 
# Due to PCC Grants
any_entr <- tabular(Heading("Estimate") * (
  `Unique users` + `Entrepreneurship trainees` + 
    `Engaged in entrepreneurial activities`) * Heading() * sum * Format(
      formatC(digits = 0, big.mark = ",", format = "f")) ~
    Heading() * Case_Study + Heading("Total") * 1, pcc.w.2)
(any_entr <- any_entr[, 3])

# Total Estimated Number Engaged in Different Entrepreneurial Activities Due to
# PCC Grants
entr_act <- tabular(Heading("Estimate") * (
  `Started a business` + `Looked for new customers` + `Grew their business`) * 
    Heading() * sum * Format(formatC(digits = 0, big.mark = ",", format = "f"))
  ~ Heading() * Case_Study + Heading("Total") * 1, pcc.w.2)
(entr_act <- entr_act[, 3])


# Write to files ####

# Total Estimated Number of Individuals Engaged in Any Entrepreneurial Activity 
# Due to PCC Grants
write.xlsx.tabular(any_entr, file.path(appC, "PCC.W.2 - Table 41.xlsx"))

# Total Estimated Number Engaged in Different Entrepreneurial Activities Due to 
# PCC Grants
write.xlsx.tabular(entr_act, file.path(appC, "PCC.W.2 - Table 42.xlsx"))
