# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load intermediate files ####

# Grants list
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Entrepreneurship training
entrain.rda <- file.path(parent.dir, "Prepared Data",
                         "PCC and SBA Entrepreneurship Training Summary.rda")
load(entrain.rda)
head(entrepreneurship)



# Calculations ####

# Becker et al. (2010): 7% engaged in "activities related to starting or 
# managing a business of their own", 3.3% started a business, 3.5% looked for 
# new customers, 1.7% grew business

# Data
sba.w.2a <- grants[Grant_Type == "SBA"][Defunded == ""] # sba grants
sba.w.2a <- entrepreneurship[sba.w.2a] # Entrepreneurship trainees
sba.w.2a[, participants := replace(participants, is.na(participants), 0)]

# Number engaged in entrepreneurial endeavors
sba.w.2a[, entrep_endeav := participants]

# Started a business
sba.w.2a[, start_business := entrep_endeav * (0.033 / .07)]

# Looked for new customers
sba.w.2a[, searched_customers := entrep_endeav * (0.035 / .07)]

# Grew business
sba.w.2a[, grew_business := entrep_endeav * (0.017 / .07)]



# Results ####
setnames(sba.w.2a, c(
  "entrep_endeav", "start_business", "searched_customers", 
  "grew_business"), c(
    "Engaged in entrepreneurial activities (entrepreneurship training attendees)",
    "Started a business", "Looked for new customers", "Grew their business"))


# Total Estimated Number Engaged in Different Entrepreneurial Activities Due to 
# SBA Grants
entr_act <- tabular(Heading("Estimate") * (
  `Engaged in entrepreneurial activities (entrepreneurship training attendees)` +
    `Started a business` + 
    `Looked for new customers` + `Grew their business`) * Heading() * sum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) ~ 
    Heading() * Case_Study + Heading("Total") * 1, sba.w.2a)
(entr_act <- entr_act[, 3])


# Write to files ####

# Total Estimated Number of Individuals Engaged in Any Entrepreneurial Activity 
# Due to SBA Grants
write.xlsx.tabular(entr_act, file.path(appC, "SBA.W.2a - Table 44.xlsx"))
