# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Functions.R"), echo = TRUE)



# Load intermediate files ####

# Grants list
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# Subscribers
subscr.rda <- file.path(parent.dir, "Prepared Data", "SBA Subscribers.rda")
load(subscr.rda)
head(sba_subscr_total)



# Calculations ####

# Grimes, Ren, and Stevens (2009) estimated that broadband adoption by a firm 
# increases the firm's productivity by 7.6 percent to 13 percent.
# A report written for the SBA Office of Advocacy notes that the majority of 
# small business entities in the United States are nonfarm sole proprietorships 
# and have an average size of $56,416

# Data
sba.w.2b <- grants[Grant_Type == "SBA"][Defunded == ""] # sba grants
sba.w.2b <- sba_subscribers[sba.w.2b] # quarterly subscribers

# How many years of business subscription by 2013-12-31?
sba.w.2b <- sba.w.2b[
  , years := as.numeric(as.Date("2013-12-31") - quarter) / 365] # years from 
                                                                # quarter
sba.w.2b[, years_new_bus_subscr := bus_quarter * years]

# Economic impact
sba.w.2b[, new_bus_subscr_total_revenue := years_new_bus_subscr * 56416]
sba.w.2b[, increased_revenue := (new_bus_subscr_total_revenue * .076) / 1e6]



# Results ####
setnames(sba.w.2b, c("bus_quarter", "years_new_bus_subscr"), c(
  "Business subscribers", "Years of business subscriptions"))
setnames(sba.w.2b, "increased_revenue", "Total economic benefit")


# Total New Business Subscribers and Years of Business Subscriptions Due to SBA 
# Grants
bus_subscr <- tabular(Heading("Measure") * (
  `Business subscribers` + `Years of business subscriptions`) * Heading() * 
    sum * Format(formatC(digits = 0, big.mark = ",", format = "f")) ~
    Heading() * Case_Study + Heading("Total") * 1, sba.w.2b)
(bus_subscr <- bus_subscr[, 3])

# Estimated Total Economic Benefit of Increased Productivity at Businesses with 
# New Broadband Subscriptions Due to SBA Grants (Million USD)
(inc_prod <- tabular(
  (Heading("Estimate") * variable) * Heading() * value * Heading() * sum * 
    Format(formatC(digits = 0, big.mark = ",", format = "f")) ~ 
    Heading() * Case_Study + Heading("Total") * 1, 
  melt(sba.w.2b, id.vars = "Case_Study",
       measure.vars = "Total economic benefit")))



# Write to files ####

# Total New Business Subscribers and Years of Business Subscriptions Due to 
# SBA Grants
write.xlsx.tabular(bus_subscr, file.path(appC, "SBA.W.2b - Table 45.xlsx"))

# Estimated Total Economic Benefit of Increased Productivity at Businesses with 
# New Broadband Subscriptions Due to SBA Grants (Million USD)
write.xlsx.tabular(inc_prod, file.path(appC, "SBA.W.2b - Table G.xlsx"))
