# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load analysis ####

# Extrapolation Table
extrapolate.rda <- file.path(parent.dir, "Statistical Analysis", 
                             "Extrapolation Table.rda")
load(extrapolate.rda)
head(extrapolate)



# Load Prepared Data ####

# Household Statistics
households.rda <- file.path(parent.dir, "Prepared Data", 
                            "Household Statistics.rda")
load(households.rda)
head(households)



# The Allen Consulting Group ####
# It is estimated that on average a household with a broadband connection values
# that connection at $148 per week.
# U.S. users use half as much as Aussies, so 148 * .5
# From ABS "Household Income and Income Distribution, Australia, 2009-10": 2 173

# Lookup
allen <- copy(extrapolate) # BTOP counties
allen <- households[allen] # household statistics

# Households that adopt
allen[, hunits_adopt := effect * adoption_rate * hunits]

# Project total value to adopters
allen[, economic_benefit := (hunits_adopt * (((148 * .5) / 2173) *
                                               household_income)) / 1e6]

# Print totals
allen[, list(benefit = sum(economic_benefit)), keyby = list(
  definition, adjustment, match.type)]



# Results ####

# Aggregate table
(val_subscr <- tabular(
  Heading("Grants") * (case + Heading("All BTOP") * 1) * 
    Heading("Match Type") * match.type ~ 
    Heading() * adjustment * Heading() * definition * Heading() * 
    economic_benefit * Heading() * sum * 
    Format(formatC(digits = 0, format = "f", big.mark = ",")), allen))

# Write
write.xlsx.tabular(val_subscr, file.path(
  appD, "D.10 Value to New Subscribers - Table 60.xlsx"))
