# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis", 
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Figure 14. Comparison of Estimated Effects with Confidence Intervals ####

# Add line wrapping to labels
d <- copy(effects.intervals)
levels(d$adjustment) <- gsub("\\s", "\n", levels(d$adjustment))
d[, adjustment := factor(adjustment, rev(levels(adjustment)))]

# Forest plot
(compare_effects_ci <- ggplot(d, aes(effect, adjustment)) + 
   facet_grid(match.type ~ definition) +
   geom_vline(aes(xintercept = 0), linetype = 2) +
   geom_segment(aes(x = lower, xend = upper, yend = adjustment, 
                    linetype = "95% Confidence Interval"),
                size = 1.5, color = "lightgrey") +
   geom_point(aes(shape = "Estimate"), size = 6) + 
   scale_shape_manual(values = 15) +
   scale_x_continuous("Effect", label = percent) +
   theme_btop() + 
   theme(axis.title.y = element_blank(),
         legend.position = "bottom",
         legend.direction = "horizontal"))

# Write to file
ggsave(file.path(appD, "Figure 14.png"), compare_effects_ci, width = 12.2,
       height = 7)
