# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Treatment and Potential Control Counties
treat.control.rda <- file.path(parent.dir, "Prepared Data",
                               "Treatment and Potential Control Counties.rda")
load(treat.control.rda)
head(control.elimination)
head(treat.control.status)



# Table. Potential Control Counties in the United States ####

# Reshape
v <- c("all", "lessakhi", "btop_app", "less_btop_bip")
county.math <- melt(control.elimination, id.vars = "fips", measure.vars = v)
county.math[, variable := factor(variable, levels = v, labels = c(
  "All counties and equivalents in the United States", 
  "Less counties in Alaska, Hawaii, and Outlying Areas", 
  "Less counties not in proposed BTOP service area",
  "Less counties in awarded BTOP or BIP grant service area"))]
county.math <- county.math[, list(N = formatC(sum(value), 0, big.mark = ",")), 
                           by = variable]

# Add final label
county.math[, label := c(rep("", 3), "Potential Controls")]

# Write
potential.xlsx <- file.path(appD, "Table 47.xlsx")
write.xlsx(county.math, potential.xlsx, row.names = FALSE, col.names = FALSE)
