# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Functions.R"), echo = TRUE)



# Load analysis ####

# Effects on Availability
effects.rda <- file.path(parent.dir, "Statistical Analysis", 
                         "Effect on Availability.rda")
load(effects.rda)
head(effects)
head(did.overall)



# Table, Estimated Total Population with Broadband Availability Due to BTOP ####

# Reshape effects
d <- melt(effects, id.vars = c("definition", "adjustment", "match.type"), 
          measure.vars = c("Evaluation Study Sample", "Rest of BTOP",
                           "All BTOP"))

# Table
(pop_with_bb <- tabular(
  Heading("Definition") * definition * Heading("Match Type") * match.type * 
    Heading("Grants") * variable ~ 
    Heading() * adjustment * Heading() * value * Heading() * identity *
    Format(formatC(big.mark = ",", digits = 0, format = "f")), d))

# Write to file
write.xlsx.tabular(pop_with_bb, file.path(appD, "Table 52.xlsx"))
