# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"),
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)



# CAC data - cleaned quantitative data about PCC locations ####

# Read 2012 file
cac12.file <- file.path(parent.dir, "Input Files", "CAC Data - 2012.xls")
pcc_cac_12 <- Read.xlsx2(cac12.file, sheetName = "PCC Sites Data",
                         colClasses = "character")

# Select columns
pcc_sites <- pcc_cac_12[, list(
  Award_Num = Award.ID, Institution.Type, PCC.Type, 
  workstations = as.numeric(Number.of.Workstations), 
  week_hours = as.numeric(Number.of.Hours.Open.Per.Week), 
  weekend_hours = as.numeric(Number.of.Hours.Open.Per.Weekend), 
  speed = as.numeric(Broadband.Access.Speed),
  week_users = as.numeric(Number.of.Users.of.Per.Week))]
setkey(pcc_sites, Award_Num)

# Create factors and collapse levels
pcc_sites[, Institution.Type := factor(Institution.Type, c(
  "", "Community Based Organization (CBO)", "Community College", 
  "For-Profit Organization", "Government Facility", 
  "Institution of Higher Education", "Library",
  "Medical or Healthcare Provider", "Non-Profit Entity", 
  "Non-Profit Organization", "Public Housing", "Public Housing ", 
  "Public Safety", "School (K-12)", "Tribal"))]
levels(pcc_sites$Institution.Type) <- c(
  "Unreported", "Community-Based Organization", "Community College",
  "For-Profit Organization", "Government Facility", 
  "Institution of Higher Education", "Library", 
  "Medical or Healthcare Provider", "Non-Profit Organization", 
  "Non-Profit Organization", "Public Housing", "Public Housing", 
  "Public Safety", "School (K-12)", "Tribal")
pcc_sites[, PCC.Type := factor(PCC.Type, c("Improved", "new", "New"))]
levels(pcc_sites$PCC.Type) <- c("Improved", "New", "New")

# Save ####
sites.rda <- file.path(parent.dir, "Prepared Data", "PCC Sites.rda")
save(pcc_sites, file = sites.rda)



# Write ####
sites.xlsx <- file.path(parent.dir, "Prepared Data", "PCC Sites.xlsx")
write.xlsx2(grants[pcc_sites], sites.xlsx, row.names = FALSE)
