# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code", 
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)

# PCC and SBA Service Areas
service.rda <- file.path(parent.dir, "Prepared Data",
                         "PCC and SBA Service Areas.rda")
load(service.rda)
head(county.areas)
head(tract.areas)



# ACS data ####

# Read file
acs.file <- file.path(parent.dir, "Input Files", 
                      "Census Bureau ACS (2005-2009) Data.csv")
acs <- fread(acs.file, colClasses = c("character", rep("numeric", 12)))
setkey(acs, fips)



# Calculate average household size ####

# Query
avg_hh_size  <- rbind(
  acs[tract.areas],
  acs[, lapply(.SD, sum), keyby = list(fips = substr(fips, 1, 5))][
    county.areas])


# Aggregate and calculate
avg_hh_size <- avg_hh_size[, list(
  avg_hh_size = sum(population) / sum(hunits_occupied)), keyby = Award_Num]


# Use national figure for VI
avg_hh_size[substr(Award_Num, 1, 2) == "78",
            avg_hh_size := acs[, sum(population) / sum(hunits_occupied)]]




# Save ####
hhsize.rda <- file.path(parent.dir, "Prepared Data",
                        "PCC and SBA Average Household Size.rda")
save(avg_hh_size, file = hhsize.rda)



# Write ####
avg_hh_size <- grants[avg_hh_size]
hhsize.file <- file.path(parent.dir, "Prepared Data", 
                         "PCC and SBA Average Household Size.xlsx")
write.xlsx(avg_hh_size, hhsize.file, row.names = FALSE)
