# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Load Prepared Data ####

# Grants
grants.rda <- file.path(parent.dir, "Prepared Data", "Grants.rda")
load(grants.rda)
head(grants)




# Job search training ####

# Read file
jsearch.file <- file.path(parent.dir, "Input Files", 
                          "PCC and SBA Job Search Training.xlsx")
job_search <- Read.xlsx2(jsearch.file, sheetIndex = 1)
job_search[, participants := as.numeric(Participants)]

# Roll up participants
job_search <- job_search[, list(participants = sum(participants)),
                         keyby = Award_Num]



# Save ####
job.rda <- file.path(parent.dir, "Prepared Data", 
                     "PCC and SBA Job Search Training Summary.rda")
save(job_search, file = job.rda)



# Write ####
job.xlsx <- file.path(parent.dir, "Prepared Data", 
                      "PCC and SBA Job Search Training Summary.xlsx")
write.xlsx(grants[job_search], job.xlsx, row.names = FALSE)
