# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", 
                 "Define Functions.R"), echo = TRUE)



# NBM data ####

# Read file
nbm.pop.file <- file.path(
  parent.dir, "Input Files", 
  "NBM Statistics, 2011-06-30 and 2013-06-30 - Population.xlsx")
pop <- Read.xlsx2(nbm.pop.file, sheetIndex = 1, 
                  colClasses = c(rep("character", 4), rep("numeric", 7)))

# Replace missing adjustment values with corresponding uandjusted values
pop[year == "2011", `:=`(bbbackward_nofa = bb_nofa, bbbackward_ntia = bb_ntia)]
pop[year == "2013", `:=`(bbforward_nofa = bb_nofa, bbforward_ntia = bb_ntia)]

# Rates
bb <- grep("bb", names(pop), value = TRUE)
pop[, bb := lapply(.SD, "/", pop[, total]), .SDcols = bb, with = FALSE]

# Differences
diff_avail <- pop[, lapply(.SD, diff), keyby = fips, .SDcols = bb]

# Standard deviation
sd_diff_avail <- diff_avail[, lapply(.SD, sd, na.rm = TRUE), .SDcols = bb]

# Reshape
sd_diff_avail <- melt(sd_diff_avail, id.vars = integer(0))[
  , variable := as.character(variable)]
sd_diff_avail[, definition := factor(ifelse(grepl("nofa", variable),
                                            "NOFA", "NTIA"))]
sd_diff_avail[, adjustment := factor(sapply(strsplit(variable, "_"), "[", 1), c(
  "bb", "bbbackward", "bbforward"), c("Availability", "Backward Looking",
                                      "Forward Looking"))]
sd_diff_avail[, variable := NULL]

# Key
setkey(sd_diff_avail, definition, adjustment)
setnames(sd_diff_avail, "value", "sd_diff_avail")



# Save ####
sd.avail.rda <- file.path(parent.dir, "Prepared Data",
                          "Standard Deviation of Availability Growth.rda")
save(sd_diff_avail, file = sd.avail.rda)



# Write ####
sd.avail.xlsx <- file.path(parent.dir, "Prepared Data",
                           "Standard Deviation of Availability Growth.xlsx")
write.xlsx(sd_diff_avail, sd.avail.xlsx, row.names = FALSE)
