# Prepare workspace ####

# Define parent directory
parent.dir <- "C:/Final Report"

# Reset workspace 
rm(list = setdiff(ls(), "parent.dir"))
gc()

# Strings as characters
options(stringsAsFactors = FALSE)

# Child directories
source(file.path(parent.dir, "Shared Source Code",
                 "Define Child Directories.R"), echo = TRUE)

# Packages
source(file.path(parent.dir, "Shared Source Code",
                 "Install and Load Packages.R"), echo = TRUE)

# Custom functions
source(file.path(parent.dir, "Shared Source Code", "Define Functions.R"), 
       echo = TRUE)



# Read data ####

# LAU 2011
lau11.file <- file.path(parent.dir, "Input Files", 
                        "BLS Local Area Unemployment Statistics - 2011.xlsx")
lau11 <- Read.xlsx2(lau11.file, colClasses = c("character", rep("numeric", 4)),
                    sheetIndex = 1)

# LAU 2012
lau12.file <- file.path(parent.dir, "Input Files", 
                        "BLS Local Area Unemployment Statistics - 2012.xlsx")
lau12 <- Read.xlsx2(lau12.file, colClasses = c("character", rep("numeric", 4)),
                    sheetIndex = 1)

# Merge 2011 and 2012
diff_empl <- merge(lau11[, list(em11 = employed), keyby = fips],
                   lau12[, list(em12 = employed), keyby = fips])

# Log-difference (percentage change) of employment
diff_empl[, diff_empl := log(em12) - log(em11)]

# Standard deviation of all log-differences
sd_diff_empl <- diff_empl[, list(sd_diff_empl = sd(diff_empl))]



# Save ####
sd.empl.rda <- file.path(parent.dir, "Prepared Data",
                         "Standard Deviation of Employment Growth.rda")
save(sd_diff_empl, file = sd.empl.rda)



# Write ####
sd.empl.xlsx <- file.path(parent.dir, "Prepared Data",
                          "Standard Deviation of Employment Growth.xlsx")
write.xlsx(sd_diff_empl, sd.empl.xlsx, row.names = FALSE)
